@@ -1,4 +1,4 @@
-PairedCI<-function (n12, t, n21, confidence.level = 0.95, alternative = "Lower", precision = 0.00001,grid.one=30,grid.two=20) 
+PairedCI<-function (n12, t, n21, conf.level = 0.95, CItype = "Two.sided", precision = 0.00001,grid.one=30,grid.two=20) 
 {
     if (length(n12) != 1 || (n12 < 0)) {
         stop("number of subjects n12 must be a positive integer")
@@ -15,24 +15,31 @@ PairedCI<-function (n12, t, n21, confidence.level = 0.95, alternative = "Lower",
     if (length(grid.two) != 1 || (grid.two < 1)) {
         stop("number of grid in the second step search grid.two must be a positive integer")
     }    
-    if (length(confidence.level) != 1 || confidence.level < 0 || confidence.level > 
+    if (length(conf.level) != 1 || conf.level < 0 || conf.level > 
         1) {
-        stop("confidence.level must be a positive number between 0 and 1, default 0.95")
+        stop("conf.level must be a positive number between 0 and 1, default 0.95")
     }
     if (length(precision) != 1 || precision < 0) {
         stop("precision must be a positive number, default 0.00001")
     }
-    alternative <- match.arg(alternative, choices = c("Lower", 
-        "Upper"))
-    CI <- PairedCIone(n12=n12, t=t, n21=n21, confidence.level = confidence.level, alternative = alternative,precision=precision,grid.one=grid.one,grid.two=grid.two)
-    Result <- list(confidence.level = confidence.level, alternative = alternative, estimate = CI[1], ExactOneCI = CI[2:3])
+    CItype <- match.arg(CItype, choices = c("Lower", 
+        "Upper","Two.sided"))
+if(CItype=="Two.sided"){
+    CIlower <- PairedCIone(n12=n12, t=t, n21=n21, conf.level = 1-(1-conf.level)/2, CItype = "Lower",precision=precision,grid.one=grid.one,grid.two=grid.two)
+    CIupper <- PairedCIone(n12=n12, t=t, n21=n21, conf.level = 1-(1-conf.level)/2, CItype = "Upper",precision=precision,grid.one=grid.one,grid.two=grid.two)
+    Result <- list(conf.level = conf.level, CItype = CItype,estimate = CIupper[1], ExactCI = c(CIlower[2],CIupper[3]))
     Result
+}else{
+    CI <- PairedCIone(n12=n12, t=t, n21=n21, conf.level = conf.level, CItype = CItype,precision=precision,grid.one=grid.one,grid.two=grid.two)
+    Result <- list(conf.level = conf.level, CItype = CItype, estimate = CI[1], ExactCI = CI[2:3])
+    Result
+     }
+
 }
 
 
 
-
-PairedCIone<-function(n12, t, n21, confidence.level, alternative,precision,grid.one,grid.two){
+PairedCIone<-function(n12, t, n21, conf.level, CItype, precision,grid.one,grid.two){
 pround=0
 while(1/precision>=10^pround)
 {pround=pround+1}
@@ -43,7 +50,7 @@ datavectorU<-(n-n12-t)*(n+2)+t
 output<-c()
 output[1]<-round(2*n12/n+t/n-1,digits=6)
 delta<-10^(-10)
-alpha=1-confidence.level
+alpha=1-conf.level
 
 f<-array(,dim=c((n+1)*(n+2)/2,7))
 S<-array(,dim=c((n+1)*(n+2)/2,2))
@@ -118,10 +125,10 @@ kk1=1
 dimoftable<-dim(Ls)[1]
 
 
-if(n12==n && t==0 && alternative=="Lower"){output[2]=Ls[1,4];output[3]=1;kk<-dimoftable}
-if(n12==0 && t==0 && alternative=="Lower"){output[2]=-1;output[3]=1;kk<-dimoftable}
-if(n12==n && t==0 && alternative=="Upper"){output[2]=-1;output[3]=1;kk<-dimoftable}  
-if(n12==0 && t==0 && alternative=="Upper"){output[2]=-1;output[3]=-Ls[1,4];kk<-dimoftable}  
+if(n12==n && t==0 && CItype=="Lower"){output[2]=Ls[1,4];output[3]=1;kk<-dimoftable}
+if(n12==0 && t==0 && CItype=="Lower"){output[2]=-1;output[3]=1;kk<-dimoftable}
+if(n12==n && t==0 && CItype=="Upper"){output[2]=-1;output[3]=1;kk<-dimoftable}  
+if(n12==0 && t==0 && CItype=="Upper"){output[2]=-1;output[3]=-Ls[1,4];kk<-dimoftable}  
 
 while(kk<=(dimoftable-2))
 {
@@ -291,14 +298,15 @@ imin=-1+delta
 
 I1<-Ls[1:morekk,1]
 I2<-Ls[1:morekk,2]
+I3<-n-I1-I2
+
+part1<-lfactorial(n)-lfactorial(I1)-lfactorial(I2)-lfactorial(I3)
 
 prob2step<-function(delv)
 {
 delvalue<-delv
-if(delvalue<0){p0<-seq(-delvalue+delta,1-delta,length=grid.one)}else{
-p0<-seq(delta,1-delvalue-delta,length=grid.one)}
-part1<-lchoose(n,I1) + I1%*%t(log(p0+delvalue)) + (n-I1)%*%t(log(1-p0-delvalue))
-part2<-lchoose(m,I2) + I2%*%t(log(p0)) + (m-I2)%*%t(log(1-p0))
+p0<-seq(delta,min(1-delvalue-delta,1+delvalue-delta),length=grid.one)
+part2<-I1%*%t(log((1+delvalue-p0)/2)) +(I2)%*%t(log(p0)) + (I3)%*%t(log((1-p0-delvalue)/2))
 sum<-part1+part2
 expsum<-exp(sum)
 sumofprob<-colSums(expsum)
@@ -308,8 +316,7 @@ maxloc<-which(sumofprob==mansum)
 lowerb<-max(p0[1],p0[maxloc]-stepv)+delta
 upperb<-min(p0[grid.one],p0[maxloc]+stepv)-delta
 p0<-seq(lowerb,upperb,length=grid.two)
-part1<-lchoose(n,I1) + I1%*%t(log(p0+delvalue)) + (n-I1)%*%t(log(1-p0-delvalue))
-part2<-lchoose(m,I2) + I2%*%t(log(p0)) + (m-I2)%*%t(log(1-p0))
+part2<-I1%*%t(log((1+delvalue-p0)/2)) +(I2)%*%t(log(p0)) + (I3)%*%t(log((1-p0-delvalue)/2))
 sum<-part1+part2
 expsum<-exp(sum)
 sumofprob<-colSums(expsum)
@@ -357,7 +364,7 @@ allvector<-setdiff(allvector,partvector)
 kk=kk+1
 }
 
-if(alternative=="Lower"){
+if(CItype=="Lower"){
 if((is.element(datavectorL,allvector)*1)==0){
    for(jj in (kk1+1):kk){
         if(Ls[jj,1]==n12 && Ls[jj,2]==t){output[2]=Ls[jj,4]}
